##  Preconfigured Processors
To get started, you can review the configuration of preconfigured processors marked with the lock icon on the Integration API page. These processors cover typical scenarios for importing data into your workspace:
  * Import Applications Example: This processor imports application fact sheets with basic attributes, tags, subscriptions, and relations.
  * Import Hierarchy Example: This processor imports business capability fact sheets with basic attributes and relation hierarchy, including parent and child fact sheets.
  * CMDB Connector Example: This processor imports data from a CMDB to your workspace, including:
    * IT component, provider, and application fact sheets
    * Relations from IT components to applications and providers
    * Links added as resources (documents) on fact sheets


You can perform test runs for these processors and preview the results in the Output Log section. Use these examples as a basis to create your own processors by copying the configuration and adjusting the scope to your needs.
![Preconfigured Processors](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741aa4e7a44101499aed257d20dd735_LowRes.png)
Preconfigured Processors
